Home
last modified time | relevance | path

Searched refs:UD (Results 1 – 25 of 40) sorted by relevance

12

/llvm-project-15.0.7/clang/test/SemaCUDA/
H A Ddevice-var-init.cu69 __device__ UD d_ud;
71 __shared__ UD s_ud;
73 __constant__ UD c_ud;
278 static __device__ UD d_ud; in df_sema()
280 static __shared__ UD s_ud; in df_sema()
282 static __constant__ UD c_ud; in df_sema()
/llvm-project-15.0.7/clang/lib/Frontend/
H A DVerifyDiagnosticConsumer.cpp302 UD.RegexKind, UD.DirectivePos, ExpectedLoc, MatchAnyFileAndLine, in attachDirective()
303 MatchAnyLine, UD.Text, UD.Min, UD.Max); in attachDirective()
307 Diags.Report(UD.ContentBegin, diag::err_verify_invalid_content) in attachDirective()
308 << (UD.RegexKind ? "regex" : "string") << Error; in attachDirective()
311 UD.DL->push_back(std::move(D)); in attachDirective()
356 for (auto &UD : Deferred->second) { in addMarker() local
358 M.UseLoc = UD.DirectivePos; in addMarker()
359 attachDirective(Diags, UD, Pos); in addMarker()
372 M.UseLoc = UD.DirectivePos; in addDirective()
373 return attachDirective(Diags, UD, M.DefLoc); in addDirective()
[all …]
/llvm-project-15.0.7/clang/test/Preprocessor/
H A Doutput_paste_avoid.cpp44 UD: StrSuffix()ident
45 UD: IntSuffix()ident
/llvm-project-15.0.7/clang/test/Layout/
H A Dms-x86-member-pointers.cpp11 struct UD { char a; int U::*mp; }; struct
76 sizeof(UD) +
/llvm-project-15.0.7/clang/include/clang/ExtractAPI/
H A DAvailabilityInfo.h57 bool UD, bool UU) in AvailabilityInfo()
59 UnconditionallyDeprecated(UD), UnconditionallyUnavailable(UU) {} in AvailabilityInfo()
/llvm-project-15.0.7/clang/test/CodeGenCUDA/Inputs/
H A Dcuda-initializers.h40 struct UD { struct
42 __device__ ~UD(); argument
/llvm-project-15.0.7/clang/test/SemaCUDA/Inputs/
H A Dcuda-initializers.h40 struct UD { struct
42 __device__ ~UD(); argument
/llvm-project-15.0.7/clang/unittests/Basic/
H A DSourceManagerTest.cpp444 const MacroDirective *UD) override { in MacroUndefined() argument
446 MacroAction(UD ? UD->getLocation() : SourceLocation(), in MacroUndefined()
448 UD ? MacroAction::kDefinition | MacroAction::kUnDefinition in MacroUndefined()
/llvm-project-15.0.7/clang/test/CodeGenCUDA/
H A Ddevice-var-init.cu233 UD ud; in df()
/llvm-project-15.0.7/llvm/lib/Transforms/Scalar/
H A DGVNHoist.cpp773 if (auto *UD = dyn_cast<MemoryUseOrDef>(D)) in safeToHoistLdSt() local
774 if (!firstInBB(UD->getMemoryInst(), NewPt)) in safeToHoistLdSt()
820 if (MemoryUseOrDef *UD = MSSA->getMemoryAccess(Insn)) in checkSafety() local
821 if (safeToHoistLdSt(T, Insn, UD, K, NumBBsOnAllPaths)) in checkSafety()
/llvm-project-15.0.7/clang/lib/Sema/
H A DSemaDeclCXX.cpp11819 if (UD) in ActOnUsingDeclaration()
11822 return UD; in ActOnUsingDeclaration()
11852 if (UD) in ActOnUsingEnumDeclaration()
11855 return UD; in ActOnUsingEnumDeclaration()
12381 return UD; in BuildUsingDeclaration()
12527 return UD; in BuildUsingDeclaration()
12536 return UD; in BuildUsingDeclaration()
12575 return UD; in BuildUsingEnumDeclaration()
12591 return UD; in BuildUsingEnumDeclaration()
12726 assert(bool(NamedContext) == (R || UD) && !(R && UD) && in CheckUsingDeclQualifier()
[all …]
H A DSemaLookup.cpp144 void visit(UsingDirectiveDecl *UD, DeclContext *EffectiveDC) { in visit() argument
145 DeclContext *NS = UD->getNominatedNamespace(); in visit()
149 addUsingDirective(UD, EffectiveDC); in visit()
159 for (auto UD : DC->using_directives()) { in addUsingDirectives() local
160 DeclContext *NS = UD->getNominatedNamespace(); in addUsingDirectives()
161 if (SemaRef.isVisible(UD) && visited.insert(NS).second) { in addUsingDirectives()
162 addUsingDirective(UD, EffectiveDC); in addUsingDirectives()
181 void addUsingDirective(UsingDirectiveDecl *UD, DeclContext *EffectiveDC) { in addUsingDirective() argument
184 DeclContext *Common = UD->getNominatedNamespace(); in addUsingDirective()
189 list.push_back(UnqualUsingEntry(UD->getNominatedNamespace(), Common)); in addUsingDirective()
H A DSemaAccess.cpp1312 if (UsingDecl *UD = dyn_cast<UsingDecl>(Shadow->getIntroducer())) { in IsMicrosoftUsingDeclarationAccessBug() local
1318 << UD->getQualifiedNameAsString() in IsMicrosoftUsingDeclarationAccessBug()
H A DSemaTemplateInstantiateDecl.cpp3355 NamedDecl *UD = SemaRef.BuildUsingDeclaration( in instantiateUnresolvedUsingDecl() local
3360 if (UD) { in instantiateUnresolvedUsingDecl()
3361 SemaRef.InstantiateAttrs(TemplateArgs, D, UD); in instantiateUnresolvedUsingDecl()
3362 SemaRef.Context.setInstantiatedFromUsingDecl(UD, D); in instantiateUnresolvedUsingDecl()
3365 return UD; in instantiateUnresolvedUsingDecl()
3385 for (auto *UD : D->expansions()) { in VisitUsingPackDecl() local
3387 SemaRef.FindInstantiatedDecl(D->getLocation(), UD, TemplateArgs)) in VisitUsingPackDecl()
/llvm-project-15.0.7/clang/lib/CodeGen/
H A DCGDebugInfo.h516 void EmitUsingDirective(const UsingDirectiveDecl &UD);
528 void EmitUsingDecl(const UsingDecl &UD);
531 void EmitUsingEnumDecl(const UsingEnumDecl &UD);
H A DCGDebugInfo.cpp5487 void CGDebugInfo::EmitUsingDirective(const UsingDirectiveDecl &UD) { in EmitUsingDirective() argument
5490 const NamespaceDecl *NSDecl = UD.getNominatedNamespace(); in EmitUsingDirective()
5493 auto Loc = UD.getLocation(); in EmitUsingDirective()
5497 getCurrentContextDescriptor(cast<Decl>(UD.getDeclContext())), in EmitUsingDirective()
5512 void CGDebugInfo::EmitUsingDecl(const UsingDecl &UD) { in EmitUsingDecl() argument
5515 assert(UD.shadow_size() && in EmitUsingDecl()
5518 for (const auto *USD : UD.shadows()) { in EmitUsingDecl()
5537 void CGDebugInfo::EmitUsingEnumDecl(const UsingEnumDecl &UD) { in EmitUsingEnumDecl() argument
5540 assert(UD.shadow_size() && in EmitUsingEnumDecl()
5544 for (const auto *USD : UD.shadows()) in EmitUsingEnumDecl()
/llvm-project-15.0.7/clang-tools-extra/clangd/
H A DAST.cpp229 if (auto *UD = llvm::dyn_cast<UsingDirectiveDecl>(&ND)) { in printName() local
231 if (auto *Qual = UD->getQualifier()) in printName()
233 UD->getNominatedNamespaceAsWritten()->printName(Out); in printName()
H A DFindTarget.cpp186 } else if (const UsingDecl *UD = dyn_cast<UsingDecl>(D)) { in add() local
188 for (const UsingShadowDecl *S : UD->shadows()) in add()
/llvm-project-15.0.7/llvm/test/DebugInfo/Generic/
H A Dsroa-larger.ll79 !17 = distinct !DISubprogram(name: "F", linkageName: "\01??0F@@QEAA@UD@@@Z", scope: !18, file: !1, …
/llvm-project-15.0.7/llvm/test/DebugInfo/COFF/
H A Dinheritance.ll96 @"?d@@3UD@@A" = dso_local local_unnamed_addr global %struct.D { %struct.B.base { i32 (...)** bitcas…
135 !1 = distinct !DIGlobalVariable(name: "d", linkageName: "?d@@3UD@@A", scope: !2, file: !3, line: 8,…
/llvm-project-15.0.7/llvm/cmake/modules/
H A DAddOCaml.cmake96 string(REGEX MATCH "(^| )[/-][UD] *NDEBUG($| )" flag_matches
/llvm-project-15.0.7/clang/lib/AST/
H A DJSONNodeDumper.cpp791 void JSONNodeDumper::VisitUsingDecl(const UsingDecl *UD) { in VisitUsingDecl() argument
793 if (const NestedNameSpecifier *NNS = UD->getQualifier()) { in VisitUsingDecl()
795 NNS->print(SOS, UD->getASTContext().getPrintingPolicy()); in VisitUsingDecl()
797 Name += UD->getNameAsString(); in VisitUsingDecl()
/llvm-project-15.0.7/clang-tools-extra/clang-move/
H A DMove.cpp680 } else if (const auto *UD = Result.Nodes.getNodeAs<NamedDecl>("using_decl")) { in run() local
681 MovedDecls.push_back(UD); in run()
/llvm-project-15.0.7/clang/include/clang/AST/
H A DJSONNodeDumper.h238 void VisitUsingDecl(const UsingDecl *UD);
/llvm-project-15.0.7/clang/lib/Headers/
H A Dhexagon_types.h651 unsigned long long UD(void) { in UD() function
1878 unsigned long long UD(void) { in UD() function

12